summaryrefslogtreecommitdiff
path: root/stun/usages
diff options
context:
space:
mode:
authorYouness Alaoui <youness.alaoui@collabora.co.uk>2010-05-19 16:13:16 -0400
committerYouness Alaoui <youness.alaoui@collabora.co.uk>2010-05-19 16:13:16 -0400
commit12902169a6f459b5cb80cc9899d45a1e711e99c7 (patch)
tree23fb3921fe862cde679ed50f7a04765b9f0c27cd /stun/usages
parente5bdf37121570bf1ff4963269c2d42c29175f4d3 (diff)
downloadlibnice-12902169a6f459b5cb80cc9899d45a1e711e99c7.tar.gz
Change the compatibility modes from DRAFT19 to RFC5245
Diffstat (limited to 'stun/usages')
-rw-r--r--stun/usages/ice.c2
-rw-r--r--stun/usages/ice.h13
2 files changed, 11 insertions, 4 deletions
diff --git a/stun/usages/ice.c b/stun/usages/ice.c
index 5977296..e469f32 100644
--- a/stun/usages/ice.c
+++ b/stun/usages/ice.c
@@ -70,7 +70,7 @@ stun_usage_ice_conncheck_create (StunAgent *agent, StunMessage *msg,
stun_agent_init_request (agent, msg, buffer, buffer_len, STUN_BINDING);
- if (compatibility == STUN_USAGE_ICE_COMPATIBILITY_DRAFT19) {
+ if (compatibility == STUN_USAGE_ICE_COMPATIBILITY_RFC5245) {
if (cand_use)
{
val = stun_message_append_flag (msg, STUN_ATTRIBUTE_USE_CANDIDATE);
diff --git a/stun/usages/ice.h b/stun/usages/ice.h
index 9fe8ea2..39bafaa 100644
--- a/stun/usages/ice.h
+++ b/stun/usages/ice.h
@@ -60,18 +60,25 @@ extern "C" {
/**
* StunUsageIceCompatibility:
* @STUN_USAGE_ICE_COMPATIBILITY_DRAFT19: The ICE compatibility with draft 19
* @STUN_USAGE_ICE_COMPATIBILITY_GOOGLE: The ICE compatibility with Google's
* implementation of ICE
* @STUN_USAGE_ICE_COMPATIBILITY_MSN: The ICE compatibility with MSN's
* implementation of ICE
+ * @STUN_USAGE_ICE_COMPATIBILITY_DRAFT19: The ICE compatibility with draft 19
*
* This enum defines which compatibility modes this ICE usage can use
+ *
+ * <warning>@STUN_USAGE_ICE_COMPATIBILITY_DRAFT19 is deprecated and should not
+ * be used in newly-written code. It is kept for compatibility reasons and
+ * represents the same compatibility as @STUN_USAGE_ICE_COMPATIBILITY_RFC5245
+ * </warning>
*/
typedef enum {
- STUN_USAGE_ICE_COMPATIBILITY_DRAFT19,
+ STUN_USAGE_ICE_COMPATIBILITY_RFC5245,
STUN_USAGE_ICE_COMPATIBILITY_GOOGLE,
STUN_USAGE_ICE_COMPATIBILITY_MSN,
+ STUN_USAGE_ICE_COMPATIBILITY_DRAFT19 = STUN_USAGE_ICE_COMPATIBILITY_RFC5245,
} StunUsageIceCompatibility;
@@ -127,7 +134,7 @@ typedef enum {
* request
*
* Builds an ICE connectivity check STUN message.
* If the compatibility is not #STUN_USAGE_ICE_COMPATIBILITY_DRAFT19, the
* @cand_use, @controlling, @priority and @tie arguments are not used.
* Returns: The length of the message built.
*/
@@ -60,18 +60,25 @@ extern "C" {
/**
* StunUsageIceCompatibility:
- * @STUN_USAGE_ICE_COMPATIBILITY_DRAFT19: The ICE compatibility with draft 19
+ * @STUN_USAGE_ICE_COMPATIBILITY_RFC5245: The ICE compatibility with RFC 5245
* @STUN_USAGE_ICE_COMPATIBILITY_GOOGLE: The ICE compatibility with Google's
* implementation of ICE
@@ -127,7 +134,7 @@ typedef enum {
*
* Builds an ICE connectivity check STUN message.
- * If the compatibility is not #STUN_USAGE_ICE_COMPATIBILITY_DRAFT19, the
+ * If the compatibility is not #STUN_USAGE_ICE_COMPATIBILITY_RFC5245, the
* @cand_use, @controlling, @priority and @tie arguments are not used.
* Returns: The length of the message built.